**6. Support and Maintenance**
=============================================

Frequently Asked Questions [FAQs]
----------------------------------

.. note::

   This FAQ page is regularly updated with troubleshooting tips for questions and issues encountered by PowNet users.

**1. I am trying to install Gurobi on macbook using** ``pip install gurobipy`` **but it doesn't work.**

  *Try the installation of gurobi through anaconda as follows:*
  
  .. code:: shell

    >>> conda config --add channels https://conda.anaconda.org/gurobi

    >>> conda install gurobi

    

Contact Information
-------------------

For questions and feedback related to PowNet, please contact Phumthep
Bunnak (pb585@cornell.edu) or Stefano Galelli (galelli@cornell.edu).
